.. _executor_index:

Executors
=========

libEnsemble's Executors can be used within user functions to provide a simple,
portable interface for running and managing user applications.

.. toctree::
   :maxdepth: 2
   :titlesonly:
   :caption: libEnsemble Executors:

   overview
   executor
   mpi_executor
   legacy_balsam_executor
   balsam_2_executor
